package com.ynet.life.mvc.upload;

import com.ynet.gene.core.GENEConstance;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.file.LifeFile;
import java.util.regex.Pattern;
import org.apache.commons.fileupload.FileItem;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_ynet_life_mvc_upload.jar:com/ynet/life/mvc/upload/UploadRequest.class */
public class UploadRequest {
    private String id;
    private Pattern fileTypePattern;
    private String bizId;
    private String opId;
    private String fileName;
    public static final TranFailException EXCEPTION_FILE_TYPE = new TranFailException("EBLN0000", "文件上传类型有误");
    public static final TranFailException EXCEPTION_FILE_CONTENT = new TranFailException("EBLN0000", "上传文件类型与内容不一致");
    private boolean checkSession = true;
    private long maxFileSize = -1;
    private String uploadFileNameFiled = "uploadFileNameFiled";
    private boolean absoluteFile = true;

    public String getBizId() {
        return this.bizId;
    }

    public void setBizId(String bizId) {
        this.bizId = bizId;
    }

    public String getOpId() {
        return this.opId;
    }

    public String getFileName() {
        return this.fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public void setOpId(String opId) {
        this.opId = opId;
    }

    public void validateType(String fileName) throws TranFailException {
        if (this.fileTypePattern == null) {
            return;
        }
        String fileType = LifeFile.getFileType(fileName);
        if (!this.fileTypePattern.matcher(fileType).matches()) {
            Trace.logError(GENEConstance.GENE_MVC, EXCEPTION_FILE_TYPE.getShowMessage());
            throw EXCEPTION_FILE_TYPE;
        }
    }

    public void validateType(FileItem item) throws TranFailException {
        this.fileName = item.getName();
        if (StringUtils.isNotEmpty(this.fileName) && this.fileName.indexOf("\\") >= 0) {
            this.fileName = StringUtils.substringAfterLast(this.fileName, "\\");
        }
        if (this.fileTypePattern == null) {
            return;
        }
        String fileType = LifeFile.getFileType(this.fileName);
        if (!this.fileTypePattern.matcher(fileType).matches()) {
            Trace.logError(GENEConstance.GENE_MVC, EXCEPTION_FILE_TYPE.getShowMessage());
            throw EXCEPTION_FILE_TYPE;
        }
        if (!VerifyFileType.getFileType(item, fileType.toLowerCase())) {
            Trace.logError(GENEConstance.GENE_MVC, EXCEPTION_FILE_CONTENT.getShowMessage());
            throw EXCEPTION_FILE_CONTENT;
        }
    }

    public void setId(String id) {
        this.id = id;
    }

    public void setMaxFileSize(String maxFileSize) {
        this.maxFileSize = Long.parseLong(maxFileSize);
    }

    public void setFileType(String fileType) {
        try {
            this.fileTypePattern = Pattern.compile(fileType);
        } catch (RuntimeException ex) {
            Trace.logError(GENEConstance.GENE_MVC, "文件类型正则表达式[" + fileType + "]格式有误", ex);
        }
    }

    public String getId() {
        return this.id;
    }

    public long getMaxFileSize() {
        return this.maxFileSize;
    }

    public boolean isCheckSession() {
        return this.checkSession;
    }

    public void setCheckSession(boolean checkSession) {
        this.checkSession = checkSession;
    }

    public void setMaxFileSize(long maxFileSize) {
        this.maxFileSize = maxFileSize;
    }

    public String getUploadFileNameFiled() {
        return this.uploadFileNameFiled;
    }

    public void setUploadFileNameFiled(String uploadFileNameFiled) {
        this.uploadFileNameFiled = uploadFileNameFiled;
    }

    public boolean isAbsoluteFile() {
        return this.absoluteFile;
    }

    public void setAbsoluteFile(boolean absoluteFile) {
        this.absoluteFile = absoluteFile;
    }
}
